rpanel) and 3D
real-time rendering system (rgl), this package provides a
user friendly GUI for estimating the minimum number of biomarkers
(variables) needed to achieve a given level of accuracy for two-group
classification problems based on microarray data.optimiseBiomarker (error,
errorTol = 0.05,
method = "RF", nTrain = 100,
sdB = 1.5,
sdW = 1,
foldAvg = 2.88,
nRep = 3)errorDbase for details."RF",
"SVM", and "KNN" for Random Forest,
Support Vector Machines, Linear Discriminant Analysis and k-Nearest
Neighbour respectively.optimiseBiomarker is a user friendly GUI for
interrogating the database of leave-one-out cross-validation errors,
errorDbase, to estimate optimal number of biomarkers for
microarray based classifications. The database is built on the basis of
simulated data using the classificationError function. The
function simData is used for simulating microarray data
for various combinations of factors such as the number of biomarkers,
training set size, biological variation, experimental variation, fold
change, replication, and correlation.simData
classificationErrorif(interactive()){
data(errorDbase)
optimiseBiomarker(error=errorDbase)
}Run the code above in your browser using DataLab